```{include} ../README.md
```

```{toctree}
:hidden:
:maxdepth: 2

Home <self>
usage/index
examples/index
reference/index
contributing
```


```{toctree}
:caption: External Links
:hidden:
PyPI <https://pypi.org/project/ACI/>
Github <https://github.com/camera-culture/ACI>
```
